function []=Calibration(fs0, time0, data0, fs1, time1, data1,a,b)
% Calibration of basic/SHM-a sensorboards
% June 19 2008, and edited in November, 2009 by Shinae Jang
% fs0   : sampling frequency of the wired sensor
% time0 : time vector for the wired sensor
% data0 : data from the wired sensor
%
% fs1   : sampling frequency of the wireless sensor
% time1 : time vector for the wireless sensor
% data1 : data from the wireless sensor
% a     : the constant to define the start of the window
% b     : the constant to define the end of the window


Tind = a*fs0+1:b*fs0;       % the window size.
Tsearch = 1;

[s1,s2,fs,Index1,Index2,CorFun] = sync_func(data1,data0(Tind),fs1,fs0,Tsearch);

t1 = 1/fs*(1:length(s1)); t2 = t1;
figure;subplot(2,1,1);plot(t1,s1,t2,s2);legend('Wireless','Wired');
title('Synchronized Time Histories after Synch');
ylabel('mg');grid on;
subplot(2,1,2);plot(t1,s1,'-x',t2,s2);legend('Wireless','Siglab');
title('Synchronized Time Histories - zoomed');xlabel('Time (sec)');
ylabel('mg');grid on;
savename1 = strcat('TimeHistory');
saveas(gcf,savename1,'fig');


% PSD, coherence, transfer function
nfft = 2^10;window = nfft;numoverlap = nfft/2;%fs = fs3;
lg = min(length(s2),length(s1));

[Psl,f1] = cpsd(s2,s2,[],numoverlap,nfft,fs);
[Pim,f2] = cpsd(s1,s1,[],numoverlap,nfft,fs);
[C,f3] = mscohere(s2(1:lg),s1(1:lg),[],[],nfft,fs);
[T,f4] = tfestimate(s2(1:lg),s1(1:lg),[],[],nfft,fs);
phase = (180/pi)*angle(T);
 
% PSD and coherence
figure;subplot(2,1,1);plot(f2,db(Pim),f1,db(Psl));legend('Wireless','Siglab');title('PSD');
ylabel('dB');grid%xlabel('freq (Hz)');
axis([0 100 floor(1.1*min(20*log10(Pim))) ceil(max(20*log10(Pim))+0.2*abs(max(20*log10(Pim))))]);
subplot(2,1,2);plot(f3,C,f3,0.9*ones(length(f3)));xlabel('f (Hz)');title('Coherence');grid
axis([0 100 0 1]);
savename3 = strcat('PSD_COHERENCE');
saveas(gcf,savename3,'fig');

% transfer function
figure;subplot(2,1,1);plot(f4,db(abs(T)));title('Transfer Function');grid;xlim([0 40]);ylabel('dB');
subplot(2,1,2);plot(f4,phase);title('Phase');xlabel('freq (Hz)');ylabel('degrees');grid;xlim([0 40])%axis([0 40 -60 0]);
savename4 = strcat('XFER');
saveas(gcf,savename4,'fig');

savename5 = strcat('file');
save(savename5,'s1','s2','fs','t1','t2','Psl','f1','Pim','f2','C','f3','T','f4');

% END of PROGRAM